@@ -26,11 +26,10 @@ public class regression_svrlight_modular {
 		svr.train();
 
 		kernel.init(feats_train, feats_test);
-		double[] out_labels = RegressionLabels.obtain_from_generic(svr.apply()).get_labels();
-		
+		double[] out_labels = LabelsFactory.to_regression(svr.apply()).get_labels();
+
 		foreach (double item in out_labels)
 		    Console.Write(item);
 
-		modshogun.exit_shogun();
 	}
 }
