@@ -228,33 +228,32 @@ bool CSVMLight::train_machine(CFeatures* data)
 		kernel->clear_normal() ;
 
 	// output some info
-	SG_DEBUG("threads = %i\n", parallel->get_num_threads()) 
-	SG_DEBUG("qpsize = %i\n", learn_parm->svm_maxqpsize) 
-	SG_DEBUG("epsilon = %1.1e\n", learn_parm->epsilon_crit) 
-	SG_DEBUG("kernel->has_property(KP_LINADD) = %i\n", kernel->has_property(KP_LINADD)) 
-	SG_DEBUG("kernel->has_property(KP_KERNCOMBINATION) = %i\n", kernel->has_property(KP_KERNCOMBINATION)) 
-	SG_DEBUG("kernel->has_property(KP_BATCHEVALUATION) = %i\n", kernel->has_property(KP_BATCHEVALUATION)) 
-	SG_DEBUG("kernel->get_optimization_type() = %s\n", kernel->get_optimization_type()==FASTBUTMEMHUNGRY ? "FASTBUTMEMHUNGRY" : "SLOWBUTMEMEFFICIENT" ) 
+	SG_DEBUG("threads = %i\n", parallel->get_num_threads())
+	SG_DEBUG("qpsize = %i\n", learn_parm->svm_maxqpsize)
+	SG_DEBUG("epsilon = %1.1e\n", learn_parm->epsilon_crit)
+	SG_DEBUG("kernel->has_property(KP_LINADD) = %i\n", kernel->has_property(KP_LINADD))
+	SG_DEBUG("kernel->has_property(KP_KERNCOMBINATION) = %i\n", kernel->has_property(KP_KERNCOMBINATION))
+	SG_DEBUG("kernel->has_property(KP_BATCHEVALUATION) = %i\n", kernel->has_property(KP_BATCHEVALUATION))
+	SG_DEBUG("kernel->get_optimization_type() = %s\n", kernel->get_optimization_type()==FASTBUTMEMHUNGRY ? "FASTBUTMEMHUNGRY" : "SLOWBUTMEMEFFICIENT" )
 	SG_DEBUG("get_solver_type() = %i\n", get_solver_type())
-	SG_DEBUG("get_linadd_enabled() = %i\n", get_linadd_enabled()) 
-	SG_DEBUG("get_batch_computation_enabled() = %i\n", get_batch_computation_enabled()) 
-	SG_DEBUG("kernel->get_num_subkernels() = %i\n", kernel->get_num_subkernels()) 
+	SG_DEBUG("get_linadd_enabled() = %i\n", get_linadd_enabled())
+	SG_DEBUG("get_batch_computation_enabled() = %i\n", get_batch_computation_enabled())
+	SG_DEBUG("kernel->get_num_subkernels() = %i\n", kernel->get_num_subkernels())
 
 	use_kernel_cache = !((kernel->get_kernel_type() == K_CUSTOM) ||
 						 (get_linadd_enabled() && kernel->has_property(KP_LINADD)));
 
-	SG_DEBUG("use_kernel_cache = %i\n", use_kernel_cache) 
+	SG_DEBUG("use_kernel_cache = %i\n", use_kernel_cache)
 
 	if (kernel->get_kernel_type() == K_COMBINED)
 	{
-		CKernel* kn = ((CCombinedKernel*)kernel)->get_first_kernel();
 
-		while (kn)
+		for (index_t k_idx=0; k_idx<((CCombinedKernel*) kernel)->get_num_kernels(); k_idx++)
 		{
+			CKernel* kn = ((CCombinedKernel*) kernel)->get_kernel(k_idx);
 			// allocate kernel cache but clean up beforehand
 			kn->resize_kernel_cache(kn->get_cache_size());
 			SG_UNREF(kn);
-			kn = ((CCombinedKernel*) kernel)->get_next_kernel();
 		}
 	}
 
@@ -432,14 +431,13 @@ void CSVMLight::svm_learn()
 	if (use_kernel_cache)
 	{
 		if (callback &&
-				(!((CCombinedKernel*)kernel)->get_append_subkernel_weights())
+				(!((CCombinedKernel*) kernel)->get_append_subkernel_weights())
 		   )
 		{
-			CCombinedKernel* k      = (CCombinedKernel*) kernel;
-			CKernel* kn = k->get_first_kernel();
-
-			while (kn)
+			CCombinedKernel* k = (CCombinedKernel*) kernel;
+			for (index_t k_idx=0; k_idx<k->get_num_kernels(); k_idx++)
 			{
+				CKernel* kn = k->get_kernel(k_idx);
 				for (i=0;i<totdoc;i++)     // fill kernel cache with unbounded SV
 					if((alpha[i]>0) && (alpha[i]<learn_parm->svm_cost[i])
 							&& (kn->kernel_cache_space_available()))
@@ -451,7 +449,6 @@ void CSVMLight::svm_learn()
 						kn->cache_kernel_row(i);
 
 				SG_UNREF(kn);
-				kn = k->get_next_kernel();
 			}
 		}
 		else
@@ -523,7 +520,7 @@ void CSVMLight::svm_learn()
 					 learn_parm->epsilon_a))
 				upsupvecnum++;
 		}
-		SG_INFO("Number of SV: %ld (including %ld at upper bound)\n",
+		SG_INFO("Number of SV: %d (including %d at upper bound)\n",
 				model->sv_num-1,upsupvecnum);
 	}
 
@@ -759,14 +756,12 @@ int32_t CSVMLight::optimize_to_convergence(int32_t* docs, int32_t* label, int32_
 				  (!((CCombinedKernel*) kernel)->get_append_subkernel_weights())
 			 )
 		  {
-			  CCombinedKernel* k      = (CCombinedKernel*) kernel;
-			  CKernel* kn = k->get_first_kernel();
-
-			  while (kn)
+			  CCombinedKernel* k = (CCombinedKernel*) kernel;
+			  for (index_t k_idx=0; k_idx<k->get_num_kernels(); k_idx++)
 			  {
+				  CKernel* kn = k->get_kernel(k_idx);
 				  kn->cache_multiple_kernel_rows(working2dnum, choosenum);
 				  SG_UNREF(kn);
-				  kn = k->get_next_kernel() ;
 			  }
 		  }
 		  else
@@ -914,9 +909,9 @@ int32_t CSVMLight::optimize_to_convergence(int32_t* docs, int32_t* label, int32_
   {
       SG_DEBUG("reactivating inactive examples\n")
       reactivate_inactive_examples(label,a,shrink_state,lin,c,totdoc,
-    		  iteration,inconsistent,
-    		  docs,aicache,
-    		  maxdiff);
+		  iteration,inconsistent,
+		  docs,aicache,
+		  maxdiff);
       SG_DEBUG("done reactivating inactive examples\n")
       /* Update to new active variables. */
       activenum=compute_index(shrink_state->active,totdoc,active2dnum);
@@ -1029,9 +1024,9 @@ void CSVMLight::optimize_svm(
     /* call the qp-subsolver */
     a_v=optimize_qp(qp,epsilon_crit_target,
 		    learn_parm->svm_maxqpsize,
-		    &(model->b),  				/* in case the optimizer gives us */
+		    &(model->b),				/* in case the optimizer gives us */
             learn_parm->svm_maxqpsize); /* the threshold for free. otherwise */
-                                   		/* b is calculated in calculate_model. */
+		/* b is calculated in calculate_model. */
     if(verbosity>=3) {
      SG_DONE()
     }
@@ -1099,7 +1094,7 @@ void CSVMLight::compute_matrices_for_optimization_parallel(
 		pthread_t* threads = SG_MALLOC(pthread_t, parallel->get_num_threads()-1);
 		S_THREAD_PARAM_KERNEL* params = SG_MALLOC(S_THREAD_PARAM_KERNEL, parallel->get_num_threads()-1);
 		int32_t step= Knum/parallel->get_num_threads();
-		//SG_DEBUG("\nkernel-step size: %i\n", step) 
+		//SG_DEBUG("\nkernel-step size: %i\n", step)
 		for (int32_t t=0; t<parallel->get_num_threads()-1; t++)
 		{
 			params[t].svmlight = this;
@@ -1294,7 +1289,7 @@ int32_t CSVMLight::calculate_svm_model(
 
     if((!b_calculated)
        && (a[i]>learn_parm->epsilon_a) && (a[i]<ex_c)) {   /* calculate b */
-     	model->b=((float64_t)label[i]*learn_parm->eps[i]-c[i]+lin[i]);
+	model->b=((float64_t)label[i]*learn_parm->eps[i]-c[i]+lin[i]);
 	b_calculated=1;
     }
   }
@@ -1533,14 +1528,15 @@ void CSVMLight::update_linear_component_mkl(
 	ASSERT(num_weights==num_kernels)
 
 	if ((kernel->get_kernel_type()==K_COMBINED) &&
-			 (!((CCombinedKernel*)kernel)->get_append_subkernel_weights()))// for combined kernel
+			 (!((CCombinedKernel*) kernel)->get_append_subkernel_weights()))// for combined kernel
 	{
-		CCombinedKernel* k      = (CCombinedKernel*) kernel;
-		CKernel* kn = k->get_first_kernel() ;
+		CCombinedKernel* k = (CCombinedKernel*) kernel;
+
 		int32_t n = 0, i, j ;
 
-		while (kn!=NULL)
+		for (index_t k_idx=0; k_idx<k->get_num_kernels(); k_idx++)
 		{
+			CKernel* kn = k->get_kernel(k_idx);
 			for (i=0;i<num;i++)
 			{
 				if(a[i] != a_old[i])
@@ -1552,7 +1548,6 @@ void CSVMLight::update_linear_component_mkl(
 			}
 
 			SG_UNREF(kn);
-			kn = k->get_next_kernel();
 			n++ ;
 		}
 	}
